# 开始吧！

欢迎使用OpenSesame! 希望我能帮到你。

<table><tr><td>

开始新实验:<br />
%(templates)s

</td><td>

%(recent_experiments)s

</td></tr></table>

想要支持OpenSesame？Easy!

[通过PayPal捐款](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=QEWKSAY4WMKRW){: .important-button}

或了解更多：

[浏览教程文件](http://osdoc.cogsci.nl){: .button}<br />
[在论坛上提问](http://forum.cogsci.nl){: .button}<br />
